======
SNOWAV
======


.. image:: https://img.shields.io/pypi/v/snowav.svg
        :target: https://pypi.python.org/pypi/snowav

.. image:: https://img.shields.io/travis/robertson-mark/snowav.svg
        :target: https://travis-ci.org/robertson-mark/snowav

.. image:: https://readthedocs.org/projects/snowav/badge/?version=latest
        :target: https://snowav.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/robertson-mark/snowav/shield.svg
     :target: https://pyup.io/repos/github/robertson-mark/snowav/
     :alt: Updates


Hydrology reporting package


* Free software: GNU General Public License v3
* Documentation: https://snowav.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

